# Simple Calculator 

A simple python calculator with the following functions :
  - Addition, subtraction, division and multiplication
  - Takes the n'th root
  - Able to reset memory and also calculate with previous value

## Installation
* Calculator requires >= Python 3 to run

#### Installation from pip and PYPI
1)  ```bash
          pip install simple_calculator_function
    ```
#### Installation as a python module:
1) Create a virtual environment
    ```sh
    $ python -m venv venv
    ```
2) Activate the virtual environment
    ```sh
    $ venv\Scripts\activate.bat
    ```
3) Install the Calculator with pip
    ```sh
    $ pip install git+https://github.com/helloworld4774/simple_calculator.git
    ```

License
----

[MIT](LICENSE)



